==> mit-scheme_11.2.orig.tar.xz: mit-scheme-11.2/tests/load.scm <==
#| -*-Scheme-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
    2017, 2018, 2019, 2020 Massachusetts Institute of Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

(let ((environment (top-level-environment '(mit inline-testing))))
  (load (merge-pathnames "unit-testing" (current-load-pathname))
	environment)
  (for-each (lambda (name)
	      (if (environment-bound? system-global-environment name)
		  (unbind-variable system-global-environment name))
	      (link-variables system-global-environment name
			      environment name))
	    '(run-inline-tests
	      run-unit-test
	      run-unit-tests
	      show-passing-results?
	      throw-test-errors?)))

==> mit-scheme_12.1.orig.tar.xz: mit-scheme-12.1/tests/load.scm <==
#| -*-Scheme-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
    2017, 2018, 2019, 2020, 2021, 2022 Massachusetts Institute of
    Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

(let ((environment (top-level-environment '(mit inline-testing))))
  (load (merge-pathnames "unit-testing" (current-load-pathname))
	environment)
  (for-each (lambda (name)
	      (if (environment-bound? system-global-environment name)
		  (unbind-variable system-global-environment name))
	      (link-variables system-global-environment name
			      environment name))
	    '(run-inline-tests
	      run-unit-test
	      run-unit-tests
	      show-passing-results?
	      throw-test-errors?)))
